==> kubernetes-model-1.0.6-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ContainerStateTerminatedFluent<T extends ContainerStateTerminatedFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String containerID;     Integer exitCode;     String finishedAt;     String message;     String reason;     Integer signal;     String startedAt;     Map<String, Object> additionalProperties = new HashMap();

    public String getContainerID(){
    return this.containerID;
    }
    public T withContainerID( String containerID){
    this.containerID=containerID; return (T) this;
    }
    public Integer getExitCode(){
    return this.exitCode;
    }
    public T withExitCode( Integer exitCode){
    this.exitCode=exitCode; return (T) this;
    }
    public String getFinishedAt(){
    return this.finishedAt;
    }
    public T withFinishedAt( String finishedAt){
    this.finishedAt=finishedAt; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public Integer getSignal(){
    return this.signal;
    }
    public T withSignal( Integer signal){
    this.signal=signal; return (T) this;
    }
    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }



}

==> kubernetes-model-1.0.14-sources.jar: annotations/io/fabric8/kubernetes/api/model/ContainerStateTerminatedFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ContainerStateTerminatedFluent<T extends ContainerStateTerminatedFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     String containerID;     Integer exitCode;     String finishedAt;     String message;     String reason;     Integer signal;     String startedAt;     Map<String, Object> additionalProperties = new HashMap();

    public String getContainerID(){
    return this.containerID;
    }
    public T withContainerID( String containerID){
    this.containerID=containerID; return (T) this;
    }
    public Integer getExitCode(){
    return this.exitCode;
    }
    public T withExitCode( Integer exitCode){
    this.exitCode=exitCode; return (T) this;
    }
    public String getFinishedAt(){
    return this.finishedAt;
    }
    public T withFinishedAt( String finishedAt){
    this.finishedAt=finishedAt; return (T) this;
    }
    public String getMessage(){
    return this.message;
    }
    public T withMessage( String message){
    this.message=message; return (T) this;
    }
    public String getReason(){
    return this.reason;
    }
    public T withReason( String reason){
    this.reason=reason; return (T) this;
    }
    public Integer getSignal(){
    return this.signal;
    }
    public T withSignal( Integer signal){
    this.signal=signal; return (T) this;
    }
    public String getStartedAt(){
    return this.startedAt;
    }
    public T withStartedAt( String startedAt){
    this.startedAt=startedAt; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
ContainerStateTerminatedFluent that = (ContainerStateTerminatedFluent) o;
if (containerID != null ? !containerID.equals(that.containerID) :that.containerID != null) return false;
if (exitCode != null ? !exitCode.equals(that.exitCode) :that.exitCode != null) return false;
if (finishedAt != null ? !finishedAt.equals(that.finishedAt) :that.finishedAt != null) return false;
if (message != null ? !message.equals(that.message) :that.message != null) return false;
if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
if (signal != null ? !signal.equals(that.signal) :that.signal != null) return false;
if (startedAt != null ? !startedAt.equals(that.startedAt) :that.startedAt != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
